import { Link, useLocation } from 'react-router-dom';
import { Button } from '@/components/ui/button';
import { useContext } from 'react';
import { AuthContext } from '@/contexts/AuthContext';
import {
  Home,
  Folder,
  FileText,
  Users,
  LogOut,
  Menu,
  X,
  Sun,
  Moon,
} from 'lucide-react';
import { useTheme } from '@/components/theme-provider';
import { useMobile } from '@/hooks/use-mobile';

type AppLayoutProps = {
  children: React.ReactNode;
};

export const AppLayout = ({ children }: AppLayoutProps) => {
  const location = useLocation();
  const { user, signOut } = useContext(AuthContext);
  const { theme, setTheme } = useTheme();
  const { isMobile, isSidebarOpen, toggleSidebar } = useMobile();

  const navigation = [
    { name: 'Dashboard', href: '/', icon: Home },
    { name: 'Projects', href: '/projects', icon: Folder },
    { name: 'Files', href: '/files', icon: FileText },
    { name: 'Invoices', href: '/invoices', icon: FileText },
    { name: 'Contacts', href: '/contacts', icon: Users },
  ];

  const isActive = (path: string) => {
    if (path === '/') {
      return location.pathname === '/';
    }
    return location.pathname.startsWith(path);
  };

  return (
    <div className="flex h-screen overflow-hidden bg-background">
      {/* Sidebar for desktop */}
      <div
        className={`${isMobile ? 'fixed inset-0 z-40 flex' : 'hidden md:flex md:flex-shrink-0'} ${isSidebarOpen ? '' : 'md:hidden'}`}
      >
        <div className="flex w-64 flex-col">
          <div className="flex min-h-0 flex-1 flex-col border-r bg-card">
            <div className="flex flex-1 flex-col overflow-y-auto pt-5 pb-4">
              <div className="flex flex-shrink-0 items-center px-4">
                <h1 className="text-xl font-bold">UGC Tracker</h1>
                {isMobile && (
                  <Button
                    variant="ghost"
                    size="icon"
                    className="ml-auto"
                    onClick={toggleSidebar}
                  >
                    <X className="h-5 w-5" />
                  </Button>
                )}
              </div>
              <nav className="mt-5 flex-1 space-y-1 px-2">
                {navigation.map((item) => {
                  const active = isActive(item.href);
                  return (
                    <Link
                      key={item.name}
                      to={item.href}
                      className={`group flex items-center px-2 py-2 text-sm font-medium rounded-md ${active ? 'bg-primary text-primary-foreground' : 'text-muted-foreground hover:bg-muted hover:text-foreground'}`}
                    >
                      <item.icon
                        className={`mr-3 h-5 w-5 flex-shrink-0 ${active ? 'text-primary-foreground' : 'text-muted-foreground group-hover:text-foreground'}`}
                        aria-hidden="true"
                      />
                      {item.name}
                    </Link>
                  );
                })}
              </nav>
            </div>
            <div className="flex flex-shrink-0 border-t p-4">
              <div className="flex items-center">
                <div>
                  <p className="text-sm font-medium text-foreground">
                    {user?.email}
                  </p>
                  <Button
                    variant="ghost"
                    className="mt-1 text-xs text-muted-foreground"
                    onClick={signOut}
                  >
                    <LogOut className="mr-2 h-4 w-4" />
                    Sign out
                  </Button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Mobile sidebar backdrop */}
      {isMobile && isSidebarOpen && (
        <div
          className="fixed inset-0 z-30 bg-black/30 transition-opacity"
          onClick={toggleSidebar}
        />
      )}

      {/* Main content */}
      <div className="flex flex-1 flex-col overflow-hidden">
        <div className="flex h-16 flex-shrink-0 border-b bg-card">
          <div className="flex flex-1 justify-between px-4">
            <div className="flex flex-1">
              {isMobile && (
                <Button
                  variant="ghost"
                  size="icon"
                  className="mr-2"
                  onClick={toggleSidebar}
                >
                  <Menu className="h-5 w-5" />
                </Button>
              )}
            </div>
            <div className="ml-4 flex items-center md:ml-6">
              <Button
                variant="ghost"
                size="icon"
                onClick={() => setTheme(theme === 'dark' ? 'light' : 'dark')}
              >
                {theme === 'dark' ? (
                  <Sun className="h-5 w-5" />
                ) : (
                  <Moon className="h-5 w-5" />
                )}
              </Button>
            </div>
          </div>
        </div>

        <main className="flex-1 overflow-y-auto bg-background">
          {children}
        </main>
      </div>
    </div>
  );
};

export default AppLayout;
