import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '@/contexts/AuthContext';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Tabs, TabsContent, TabsList, TabsTrigger } from '@/components/ui/tabs';
import { useToast } from '@/components/ui/use-toast';

const TwoFactorForm: React.FC = () => {
  const [phone, setPhone] = useState('');
  const [token, setToken] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const [codeSent, setCodeSent] = useState(false);
  const { requestOTP, verifyOTP } = useAuth();
  const navigate = useNavigate();
  const { toast } = useToast();

  const handleSendCode = async (e: React.FormEvent) => {
    e.preventDefault();
    setIsLoading(true);

    try {
      const { error } = await requestOTP(phone);
      if (error) {
        toast({
          variant: 'destructive',
          title: 'Failed to send code',
          description: error.message,
        });
      } else {
        setCodeSent(true);
        toast({
          title: 'Code sent',
          description: 'A verification code has been sent to your phone',
        });
      }
    } catch (err: any) {
      toast({
        variant: 'destructive',
        title: 'Error',
        description: err.message || 'An unexpected error occurred',
      });
    } finally {
      setIsLoading(false);
    }
  };

  const handleVerifyCode = async (e: React.FormEvent) => {
    e.preventDefault();
    setIsLoading(true);

    try {
      const { error } = await verifyOTP(phone, token);
      if (error) {
        toast({
          variant: 'destructive',
          title: 'Verification failed',
          description: error.message,
        });
      } else {
        toast({
          title: 'Verification successful',
          description: 'You have been authenticated successfully',
        });
        navigate('/');
      }
    } catch (err: any) {
      toast({
        variant: 'destructive',
        title: 'Error',
        description: err.message || 'An unexpected error occurred',
      });
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <Card className="w-full max-w-md mx-auto">
      <CardHeader>
        <CardTitle>Two-Factor Authentication</CardTitle>
        <CardDescription>Verify your identity with a second factor</CardDescription>
      </CardHeader>
      <CardContent>
        <Tabs defaultValue="sms">
          <TabsList className="grid w-full grid-cols-2">
            <TabsTrigger value="sms">SMS</TabsTrigger>
            <TabsTrigger value="authenticator">Authenticator App</TabsTrigger>
          </TabsList>
          
          <TabsContent value="sms" className="space-y-4">
            {!codeSent ? (
              <form onSubmit={handleSendCode} className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="phone">Phone Number</Label>
                  <Input
                    id="phone"
                    type="tel"
                    placeholder="+1234567890"
                    value={phone}
                    onChange={(e) => setPhone(e.target.value)}
                    required
                  />
                </div>
                <Button type="submit" className="w-full" disabled={isLoading}>
                  {isLoading ? 'Sending code...' : 'Send Verification Code'}
                </Button>
              </form>
            ) : (
              <form onSubmit={handleVerifyCode} className="space-y-4">
                <div className="space-y-2">
                  <Label htmlFor="token">Verification Code</Label>
                  <Input
                    id="token"
                    type="text"
                    placeholder="123456"
                    value={token}
                    onChange={(e) => setToken(e.target.value)}
                    required
                  />
                </div>
                <Button type="submit" className="w-full" disabled={isLoading}>
                  {isLoading ? 'Verifying...' : 'Verify Code'}
                </Button>
              </form>
            )}
          </TabsContent>
          
          <TabsContent value="authenticator" className="space-y-4">
            <div className="text-center space-y-4">
              <p>Enter the code from your authenticator app</p>
              <div className="space-y-2">
                <Label htmlFor="authToken">Authentication Code</Label>
                <Input
                  id="authToken"
                  type="text"
                  placeholder="123456"
                  maxLength={6}
                />
              </div>
              <Button className="w-full">
                Verify
              </Button>
            </div>
          </TabsContent>
        </Tabs>
      </CardContent>
      <CardFooter>
        <Button variant="link" className="w-full" onClick={() => navigate('/login')}>
          Back to Login
        </Button>
      </CardFooter>
    </Card>
  );
};

export default TwoFactorForm;
