import React, { createContext, useContext, useState, useEffect } from 'react';
import { Project, Invoice } from '@/types/project';
import { toast } from '@/components/ui/use-toast';
import { v4 as uuidv4 } from 'uuid';

interface ProjectContextType {
  projects: Project[];
  invoices: Invoice[];
  addProject: (project: Omit<Project, 'id' | 'createdAt' | 'updatedAt' | 'files'>) => void;
  updateProject: (id: string, project: Partial<Project>) => void;
  deleteProject: (id: string) => void;
  addInvoice: (invoice: Omit<Invoice, 'id' | 'createdAt'>) => void;
  updateInvoice: (id: string, invoice: Partial<Invoice>) => void;
  deleteInvoice: (id: string) => void;
  getProjectById: (id: string) => Project | undefined;
  getInvoiceById: (id: string) => Invoice | undefined;
  getInvoicesByProjectId: (projectId: string) => Invoice[];
}

const defaultProjectContext: ProjectContextType = {
  projects: [],
  invoices: [],
  addProject: () => {},
  updateProject: () => {},
  deleteProject: () => {},
  addInvoice: () => {},
  updateInvoice: () => {},
  deleteInvoice: () => {},
  getProjectById: () => undefined,
  getInvoiceById: () => undefined,
  getInvoicesByProjectId: () => [],
};

const ProjectContext = createContext<ProjectContextType>(defaultProjectContext);

export const useProjectContext = () => useContext(ProjectContext);

export const ProjectProvider: React.FC<{ children: React.ReactNode }> = ({ children }) => {
  const [projects, setProjects] = useState<Project[]>([]);
  const [invoices, setInvoices] = useState<Invoice[]>([]);

  // Load data from localStorage on mount
  useEffect(() => {
    const savedProjects = localStorage.getItem('projects');
    const savedInvoices = localStorage.getItem('invoices');
    
    if (savedProjects) {
      setProjects(JSON.parse(savedProjects));
    }
    
    if (savedInvoices) {
      setInvoices(JSON.parse(savedInvoices));
    }
  }, []);

  // Save data to localStorage whenever it changes
  useEffect(() => {
    localStorage.setItem('projects', JSON.stringify(projects));
  }, [projects]);

  useEffect(() => {
    localStorage.setItem('invoices', JSON.stringify(invoices));
  }, [invoices]);

  const addProject = (project: Omit<Project, 'id' | 'createdAt' | 'updatedAt' | 'files'>) => {
    const newProject: Project = {
      ...project,
      id: uuidv4(),
      files: [],
      createdAt: new Date().toISOString(),
      updatedAt: new Date().toISOString(),
    };
    
    setProjects([...projects, newProject]);
    toast({
      title: 'Project added',
      description: `${newProject.company} - ${newProject.brand} project has been added.`,
    });
  };

  const updateProject = (id: string, projectUpdate: Partial<Project>) => {
    setProjects(projects.map(project => {
      if (project.id === id) {
        return {
          ...project,
          ...projectUpdate,
          updatedAt: new Date().toISOString(),
        };
      }
      return project;
    }));
    
    toast({
      title: 'Project updated',
      description: 'The project has been updated successfully.',
    });
  };

  const deleteProject = (id: string) => {
    setProjects(projects.filter(project => project.id !== id));
    // Also delete related invoices
    setInvoices(invoices.filter(invoice => invoice.projectId !== id));
    
    toast({
      title: 'Project deleted',
      description: 'The project and its invoices have been deleted.',
      variant: 'destructive',
    });
  };

  const addInvoice = (invoice: Omit<Invoice, 'id' | 'createdAt'>) => {
    const newInvoice: Invoice = {
      ...invoice,
      id: uuidv4(),
      createdAt: new Date().toISOString(),
    };
    
    setInvoices([...invoices, newInvoice]);
    toast({
      title: 'Invoice created',
      description: `Invoice for $${newInvoice.amount} has been created.`,
    });
  };

  const updateInvoice = (id: string, invoiceUpdate: Partial<Invoice>) => {
    setInvoices(invoices.map(invoice => {
      if (invoice.id === id) {
        return { ...invoice, ...invoiceUpdate };
      }
      return invoice;
    }));
    
    toast({
      title: 'Invoice updated',
      description: 'The invoice has been updated successfully.',
    });
  };

  const deleteInvoice = (id: string) => {
    setInvoices(invoices.filter(invoice => invoice.id !== id));
    
    toast({
      title: 'Invoice deleted',
      description: 'The invoice has been deleted.',
      variant: 'destructive',
    });
  };

  const getProjectById = (id: string) => {
    return projects.find(project => project.id === id);
  };

  const getInvoiceById = (id: string) => {
    return invoices.find(invoice => invoice.id === id);
  };

  const getInvoicesByProjectId = (projectId: string) => {
    return invoices.filter(invoice => invoice.projectId === projectId);
  };

  return (
    <ProjectContext.Provider
      value={{
        projects,
        invoices,
        addProject,
        updateProject,
        deleteProject,
        addInvoice,
        updateInvoice,
        deleteInvoice,
        getProjectById,
        getInvoiceById,
        getInvoicesByProjectId,
      }}
    >
      {children}
    </ProjectContext.Provider>
  );
};