import React from 'react';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { ProjectCard } from '@/components/projects/ProjectCard';
import { useProjectContext } from '@/contexts/ProjectContext';
import { Button } from '@/components/ui/button';
import { Plus } from 'lucide-react';
import { useNavigate } from 'react-router-dom';
import { ContactSummary } from '@/components/contacts/ContactSummary';
import { ContactList } from '@/components/contacts/ContactList';

const Dashboard: React.FC = () => {
  const { projects } = useProjectContext();
  const navigate = useNavigate();

  const pendingProjects = projects.filter(p => p.status === 'pending').length;
  const inProgressProjects = projects.filter(p => p.status === 'in-progress').length;
  const completedProjects = projects.filter(p => p.status === 'completed').length;
  
  const totalEarned = projects
    .filter(p => p.paymentReceived)
    .reduce((sum, p) => sum + p.projectAmount, 0);
  
  const totalPending = projects
    .filter(p => !p.paymentReceived)
    .reduce((sum, p) => sum + p.projectAmount, 0);

  const recentProjects = [...projects]
    .sort((a, b) => new Date(b.updatedAt).getTime() - new Date(a.updatedAt).getTime())
    .slice(0, 3);

  return (
    <div className="p-8 pt-6">
      <div className="flex justify-between items-center mb-6">
        <h1 className="text-3xl font-bold tracking-tight">Dashboard</h1>
        <Button onClick={() => navigate('/projects/new')}>
          <Plus className="mr-2 h-4 w-4" /> New Project
        </Button>
      </div>

      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-5">
        <Card className="lg:col-span-1">
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Total Projects</CardTitle>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">{projects.length}</div>
          </CardContent>
        </Card>
        <Card className="lg:col-span-1">
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">In Progress</CardTitle>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">{inProgressProjects}</div>
          </CardContent>
        </Card>
        <Card className="lg:col-span-1">
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Total Earned</CardTitle>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">${totalEarned.toLocaleString()}</div>
          </CardContent>
        </Card>
        <Card className="lg:col-span-1">
          <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
            <CardTitle className="text-sm font-medium">Pending Payments</CardTitle>
          </CardHeader>
          <CardContent>
            <div className="text-2xl font-bold">${totalPending.toLocaleString()}</div>
          </CardContent>
        </Card>
        
        {/* Contact Summary Card */}
        <ContactSummary />
      </div>

      <h2 className="text-xl font-semibold mt-8 mb-4">Recent Projects</h2>
      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-3">
        {recentProjects.map(project => (
          <ProjectCard 
            key={project.id} 
            project={project} 
            onView={(id) => navigate(`/projects/${id}`)} 
            onEdit={(id) => navigate(`/projects/${id}/edit`)}
          />
        ))}
        {recentProjects.length === 0 && (
          <p className="text-muted-foreground col-span-3 text-center py-8">
            No projects yet. Create your first project to get started.
          </p>
        )}
      </div>

      <h2 className="text-xl font-semibold mt-8 mb-4">Recent Contacts</h2>
      <ContactList 
        limit={3} 
        onEdit={(id) => console.log('Edit contact', id)} 
        onDelete={(id) => console.log('Delete contact', id)} 
      />
    </div>
  );
};

export default Dashboard;
